@@ -16,7 +16,8 @@ from conans.model.ref import ConanFileReference
 from conans.model.graph_lock import GraphLockFile
 from sense2.client.cmd.create import create
 from conans.client.graph.graph_manager import GraphManager
-from conans.client.loader import ConanFileLoader
+from conans.util.files import save_files
+
 
 
 default_manifest_folder = default_manifest_folder_co
@@ -221,5 +222,31 @@ class Sense2APIV1(ConanAPIV1_co):
     #     conanfile.exports_sources = os.path.join(source_folder, "*")
     #     print("set exports_sources: ", conanfile.exports_sources)
 
+    @api_method
+    def new(self, name, header=False, pure_c=False, test=False, exports_sources=False, bare=False,
+            cwd=None, visual_versions=None, linux_gcc_versions=None, linux_clang_versions=None,
+            osx_clang_versions=None, shared=None, upload_url=None, gitignore=None,
+            gitlab_gcc_versions=None, gitlab_clang_versions=None,
+            circleci_gcc_versions=None, circleci_clang_versions=None, circleci_osx_versions=None,
+            template=None, defines=None):
+        from sense2.client.cmd.new import cmd_new
+        cwd = os.path.abspath(cwd or os.getcwd())
+        files = cmd_new(name, header=header, pure_c=pure_c, test=test,
+                        exports_sources=exports_sources, bare=bare,
+                        visual_versions=visual_versions,
+                        linux_gcc_versions=linux_gcc_versions,
+                        linux_clang_versions=linux_clang_versions,
+                        osx_clang_versions=osx_clang_versions, shared=shared,
+                        upload_url=upload_url, gitignore=gitignore,
+                        gitlab_gcc_versions=gitlab_gcc_versions,
+                        gitlab_clang_versions=gitlab_clang_versions,
+                        circleci_gcc_versions=circleci_gcc_versions,
+                        circleci_clang_versions=circleci_clang_versions,
+                        circleci_osx_versions=circleci_osx_versions,
+                        template=template, cache=self.app.cache, defines=defines)
+
+        save_files(cwd, files)
+        for f in sorted(files):
+            self.app.out.success("File saved: %s" % f)
         
 Sense2 = Sense2APIV1
